# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: minknow/rpc/manager.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from minknow.rpc import instance_pb2 as minknow_dot_rpc_dot_instance__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='minknow/rpc/manager.proto',
  package='ont.rpc.manager',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x19minknow/rpc/manager.proto\x12\x0font.rpc.manager\x1a\x1aminknow/rpc/instance.proto\"\x15\n\x13\x44\x65scribeHostRequest\"g\n\x14\x44\x65scribeHostResponse\x12\x14\n\x0cproduct_code\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06serial\x18\x03 \x01(\t\x12\x14\n\x0cnetwork_name\x18\x04 \x01(\t\"\x87\x04\n\x10\x46lowCellPosition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12<\n\x08location\x18\x02 \x01(\x0b\x32*.ont.rpc.manager.FlowCellPosition.Location\x12\x36\n\x05state\x18\x03 \x01(\x0e\x32\'.ont.rpc.manager.FlowCellPosition.State\x12=\n\trpc_ports\x18\x04 \x01(\x0b\x32*.ont.rpc.manager.FlowCellPosition.RpcPorts\x12\x12\n\nerror_info\x18\x05 \x01(\t\x1a \n\x08Location\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05\x1a`\n\x08RpcPorts\x12\x0e\n\x06secure\x18\x01 \x01(\r\x12\x10\n\x08insecure\x18\x02 \x01(\r\x12\x17\n\x0fsecure_grpc_web\x18\x03 \x01(\r\x12\x19\n\x11insecure_grpc_web\x18\x04 \x01(\r\"\x97\x01\n\x05State\x12\x16\n\x12STATE_INITIALISING\x10\x00\x12\x11\n\rSTATE_RUNNING\x10\x01\x12\x13\n\x0fSTATE_RESETTING\x10\x02\x12\x1a\n\x16STATE_HARDWARE_REMOVED\x10\x03\x12\x18\n\x14STATE_HARDWARE_ERROR\x10\x04\x12\x18\n\x14STATE_SOFTWARE_ERROR\x10\x05\"\x1a\n\x18\x46lowCellPositionsRequest\"f\n\x19\x46lowCellPositionsResponse\x12\x13\n\x0btotal_count\x18\x01 \x01(\x05\x12\x34\n\tpositions\x18\x02 \x03(\x0b\x32!.ont.rpc.manager.FlowCellPosition\"\x1f\n\x1dWatchFlowCellPositionsRequest\"\x9c\x01\n\x1eWatchFlowCellPositionsResponse\x12\x34\n\tadditions\x18\x01 \x03(\x0b\x32!.ont.rpc.manager.FlowCellPosition\x12\x32\n\x07\x63hanges\x18\x02 \x03(\x0b\x32!.ont.rpc.manager.FlowCellPosition\x12\x10\n\x08removals\x18\x03 \x03(\t\"7\n\x14ResetPositionRequest\x12\x10\n\x08position\x18\x01 \x01(\t\x12\r\n\x05\x66orce\x18\x02 \x01(\x08\"\x17\n\x15ResetPositionResponse\"\x14\n\x12ListDevicesRequest\"\xb3\x03\n\x13ListDevicesResponse\x12\x10\n\x08inactive\x18\x01 \x03(\t\x12\x0f\n\x07pending\x18\x02 \x03(\t\x12\x41\n\x06\x61\x63tive\x18\x03 \x03(\x0b\x32\x31.ont.rpc.manager.ListDevicesResponse.ActiveDevice\x1ap\n\x08RpcPorts\x12\x0f\n\x07jsonrpc\x18\x01 \x01(\r\x12\x16\n\x0ejson_websocket\x18\x02 \x01(\r\x12\x0e\n\x06secure\x18\x03 \x01(\r\x12\x15\n\rinsecure_grpc\x18\x04 \x01(\r\x12\x14\n\x0cinsecure_web\x18\x05 \x01(\r\x1a$\n\x0c\x44\x65viceLayout\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05\x1a\x9d\x01\n\x0c\x41\x63tiveDevice\x12\x0c\n\x04name\x18\x01 \x01(\t\x12<\n\x05ports\x18\x02 \x01(\x0b\x32-.ont.rpc.manager.ListDevicesResponse.RpcPorts\x12\x41\n\x06layout\x18\x03 \x01(\x0b\x32\x31.ont.rpc.manager.ListDevicesResponse.DeviceLayout\"\x16\n\x14\x42\x61secallerApiRequest\"m\n\x15\x42\x61secallerApiResponse\x12\x0e\n\x06secure\x18\x01 \x01(\r\x12\x10\n\x08insecure\x18\x02 \x01(\r\x12\x17\n\x0fsecure_grpc_web\x18\x03 \x01(\r\x12\x19\n\x11insecure_grpc_web\x18\x04 \x01(\r\"\x17\n\x15GetVersionInfoRequest\"\xc2\x02\n\x16GetVersionInfoResponse\x12H\n\x07minknow\x18\x01 \x01(\x0b\x32\x37.ont.rpc.instance.GetVersionInfoResponse.MinknowVersion\x12\x11\n\tprotocols\x18\x02 \x01(\t\x12\x1c\n\x14\x64istribution_version\x18\x03 \x01(\t\x12X\n\x13\x64istribution_status\x18\x04 \x01(\x0e\x32;.ont.rpc.instance.GetVersionInfoResponse.DistributionStatus\x12\x1b\n\x13guppy_build_version\x18\x05 \x01(\t\x12\x1f\n\x17guppy_connected_version\x18\x06 \x01(\t\x12\x15\n\rconfiguration\x18\x07 \x01(\t\"1\n!ListProtocolOutputDirFilesRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\"\xf4\x01\n\"ListProtocolOutputDirFilesResponse\x12V\n\x0b\x64irectories\x18\x01 \x03(\x0b\x32\x41.ont.rpc.manager.ListProtocolOutputDirFilesResponse.DirectoryInfo\x12\r\n\x05\x66iles\x18\x02 \x03(\t\x12\x1b\n\x13\x63urrent_listed_path\x18\x03 \x01(\t\x1aJ\n\rDirectoryInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0f\x64irectory_count\x18\x02 \x01(\x05\x12\x12\n\nfile_count\x18\x03 \x01(\x05\";\n\x16\x43reateDirectoryRequest\x12\x13\n\x0bparent_path\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\'\n\x17\x43reateDirectoryResponse\x12\x0c\n\x04path\x18\x01 \x01(\t2\xe8\x07\n\x0eManagerService\x12^\n\rdescribe_host\x12$.ont.rpc.manager.DescribeHostRequest\x1a%.ont.rpc.manager.DescribeHostResponse\"\x00\x12[\n\x0clist_devices\x12#.ont.rpc.manager.ListDevicesRequest\x1a$.ont.rpc.manager.ListDevicesResponse\"\x00\x12p\n\x13\x66low_cell_positions\x12).ont.rpc.manager.FlowCellPositionsRequest\x1a*.ont.rpc.manager.FlowCellPositionsResponse\"\x00\x30\x01\x12\x80\x01\n\x19watch_flow_cell_positions\x12..ont.rpc.manager.WatchFlowCellPositionsRequest\x1a/.ont.rpc.manager.WatchFlowCellPositionsResponse\"\x00\x30\x01\x12\x61\n\x0ereset_position\x12%.ont.rpc.manager.ResetPositionRequest\x1a&.ont.rpc.manager.ResetPositionResponse\"\x00\x12\x61\n\x0e\x62\x61secaller_api\x12%.ont.rpc.manager.BasecallerApiRequest\x1a&.ont.rpc.manager.BasecallerApiResponse\"\x00\x12\x65\n\x10get_version_info\x12&.ont.rpc.manager.GetVersionInfoRequest\x1a\'.ont.rpc.manager.GetVersionInfoResponse\"\x00\x12\x8d\x01\n\x1elist_protocol_output_dir_files\x12\x32.ont.rpc.manager.ListProtocolOutputDirFilesRequest\x1a\x33.ont.rpc.manager.ListProtocolOutputDirFilesResponse\"\x00\x30\x01\x12g\n\x10\x63reate_directory\x12\'.ont.rpc.manager.CreateDirectoryRequest\x1a(.ont.rpc.manager.CreateDirectoryResponse\"\x00\x62\x06proto3'
  ,
  dependencies=[minknow_dot_rpc_dot_instance__pb2.DESCRIPTOR,])



_FLOWCELLPOSITION_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='ont.rpc.manager.FlowCellPosition.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_INITIALISING', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATE_RUNNING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATE_RESETTING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATE_HARDWARE_REMOVED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATE_HARDWARE_ERROR', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATE_SOFTWARE_ERROR', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=571,
  serialized_end=722,
)
_sym_db.RegisterEnumDescriptor(_FLOWCELLPOSITION_STATE)


_DESCRIBEHOSTREQUEST = _descriptor.Descriptor(
  name='DescribeHostRequest',
  full_name='ont.rpc.manager.DescribeHostRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=74,
  serialized_end=95,
)


_DESCRIBEHOSTRESPONSE = _descriptor.Descriptor(
  name='DescribeHostResponse',
  full_name='ont.rpc.manager.DescribeHostResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='product_code', full_name='ont.rpc.manager.DescribeHostResponse.product_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='ont.rpc.manager.DescribeHostResponse.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serial', full_name='ont.rpc.manager.DescribeHostResponse.serial', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='network_name', full_name='ont.rpc.manager.DescribeHostResponse.network_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=200,
)


_FLOWCELLPOSITION_LOCATION = _descriptor.Descriptor(
  name='Location',
  full_name='ont.rpc.manager.FlowCellPosition.Location',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='ont.rpc.manager.FlowCellPosition.Location.x', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='ont.rpc.manager.FlowCellPosition.Location.y', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=438,
  serialized_end=470,
)

_FLOWCELLPOSITION_RPCPORTS = _descriptor.Descriptor(
  name='RpcPorts',
  full_name='ont.rpc.manager.FlowCellPosition.RpcPorts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='secure', full_name='ont.rpc.manager.FlowCellPosition.RpcPorts.secure', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insecure', full_name='ont.rpc.manager.FlowCellPosition.RpcPorts.insecure', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secure_grpc_web', full_name='ont.rpc.manager.FlowCellPosition.RpcPorts.secure_grpc_web', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insecure_grpc_web', full_name='ont.rpc.manager.FlowCellPosition.RpcPorts.insecure_grpc_web', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=472,
  serialized_end=568,
)

_FLOWCELLPOSITION = _descriptor.Descriptor(
  name='FlowCellPosition',
  full_name='ont.rpc.manager.FlowCellPosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='ont.rpc.manager.FlowCellPosition.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='ont.rpc.manager.FlowCellPosition.location', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='ont.rpc.manager.FlowCellPosition.state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rpc_ports', full_name='ont.rpc.manager.FlowCellPosition.rpc_ports', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_info', full_name='ont.rpc.manager.FlowCellPosition.error_info', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_FLOWCELLPOSITION_LOCATION, _FLOWCELLPOSITION_RPCPORTS, ],
  enum_types=[
    _FLOWCELLPOSITION_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=722,
)


_FLOWCELLPOSITIONSREQUEST = _descriptor.Descriptor(
  name='FlowCellPositionsRequest',
  full_name='ont.rpc.manager.FlowCellPositionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=724,
  serialized_end=750,
)


_FLOWCELLPOSITIONSRESPONSE = _descriptor.Descriptor(
  name='FlowCellPositionsResponse',
  full_name='ont.rpc.manager.FlowCellPositionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_count', full_name='ont.rpc.manager.FlowCellPositionsResponse.total_count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='positions', full_name='ont.rpc.manager.FlowCellPositionsResponse.positions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=752,
  serialized_end=854,
)


_WATCHFLOWCELLPOSITIONSREQUEST = _descriptor.Descriptor(
  name='WatchFlowCellPositionsRequest',
  full_name='ont.rpc.manager.WatchFlowCellPositionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=856,
  serialized_end=887,
)


_WATCHFLOWCELLPOSITIONSRESPONSE = _descriptor.Descriptor(
  name='WatchFlowCellPositionsResponse',
  full_name='ont.rpc.manager.WatchFlowCellPositionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='additions', full_name='ont.rpc.manager.WatchFlowCellPositionsResponse.additions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='changes', full_name='ont.rpc.manager.WatchFlowCellPositionsResponse.changes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='removals', full_name='ont.rpc.manager.WatchFlowCellPositionsResponse.removals', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=890,
  serialized_end=1046,
)


_RESETPOSITIONREQUEST = _descriptor.Descriptor(
  name='ResetPositionRequest',
  full_name='ont.rpc.manager.ResetPositionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='ont.rpc.manager.ResetPositionRequest.position', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='force', full_name='ont.rpc.manager.ResetPositionRequest.force', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1048,
  serialized_end=1103,
)


_RESETPOSITIONRESPONSE = _descriptor.Descriptor(
  name='ResetPositionResponse',
  full_name='ont.rpc.manager.ResetPositionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1105,
  serialized_end=1128,
)


_LISTDEVICESREQUEST = _descriptor.Descriptor(
  name='ListDevicesRequest',
  full_name='ont.rpc.manager.ListDevicesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1130,
  serialized_end=1150,
)


_LISTDEVICESRESPONSE_RPCPORTS = _descriptor.Descriptor(
  name='RpcPorts',
  full_name='ont.rpc.manager.ListDevicesResponse.RpcPorts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='jsonrpc', full_name='ont.rpc.manager.ListDevicesResponse.RpcPorts.jsonrpc', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='json_websocket', full_name='ont.rpc.manager.ListDevicesResponse.RpcPorts.json_websocket', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secure', full_name='ont.rpc.manager.ListDevicesResponse.RpcPorts.secure', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insecure_grpc', full_name='ont.rpc.manager.ListDevicesResponse.RpcPorts.insecure_grpc', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insecure_web', full_name='ont.rpc.manager.ListDevicesResponse.RpcPorts.insecure_web', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1278,
  serialized_end=1390,
)

_LISTDEVICESRESPONSE_DEVICELAYOUT = _descriptor.Descriptor(
  name='DeviceLayout',
  full_name='ont.rpc.manager.ListDevicesResponse.DeviceLayout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='ont.rpc.manager.ListDevicesResponse.DeviceLayout.x', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='ont.rpc.manager.ListDevicesResponse.DeviceLayout.y', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1392,
  serialized_end=1428,
)

_LISTDEVICESRESPONSE_ACTIVEDEVICE = _descriptor.Descriptor(
  name='ActiveDevice',
  full_name='ont.rpc.manager.ListDevicesResponse.ActiveDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='ont.rpc.manager.ListDevicesResponse.ActiveDevice.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ports', full_name='ont.rpc.manager.ListDevicesResponse.ActiveDevice.ports', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='layout', full_name='ont.rpc.manager.ListDevicesResponse.ActiveDevice.layout', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1431,
  serialized_end=1588,
)

_LISTDEVICESRESPONSE = _descriptor.Descriptor(
  name='ListDevicesResponse',
  full_name='ont.rpc.manager.ListDevicesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='inactive', full_name='ont.rpc.manager.ListDevicesResponse.inactive', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pending', full_name='ont.rpc.manager.ListDevicesResponse.pending', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active', full_name='ont.rpc.manager.ListDevicesResponse.active', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LISTDEVICESRESPONSE_RPCPORTS, _LISTDEVICESRESPONSE_DEVICELAYOUT, _LISTDEVICESRESPONSE_ACTIVEDEVICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1153,
  serialized_end=1588,
)


_BASECALLERAPIREQUEST = _descriptor.Descriptor(
  name='BasecallerApiRequest',
  full_name='ont.rpc.manager.BasecallerApiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1590,
  serialized_end=1612,
)


_BASECALLERAPIRESPONSE = _descriptor.Descriptor(
  name='BasecallerApiResponse',
  full_name='ont.rpc.manager.BasecallerApiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='secure', full_name='ont.rpc.manager.BasecallerApiResponse.secure', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insecure', full_name='ont.rpc.manager.BasecallerApiResponse.insecure', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secure_grpc_web', full_name='ont.rpc.manager.BasecallerApiResponse.secure_grpc_web', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insecure_grpc_web', full_name='ont.rpc.manager.BasecallerApiResponse.insecure_grpc_web', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1614,
  serialized_end=1723,
)


_GETVERSIONINFOREQUEST = _descriptor.Descriptor(
  name='GetVersionInfoRequest',
  full_name='ont.rpc.manager.GetVersionInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1725,
  serialized_end=1748,
)


_GETVERSIONINFORESPONSE = _descriptor.Descriptor(
  name='GetVersionInfoResponse',
  full_name='ont.rpc.manager.GetVersionInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='minknow', full_name='ont.rpc.manager.GetVersionInfoResponse.minknow', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='protocols', full_name='ont.rpc.manager.GetVersionInfoResponse.protocols', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='distribution_version', full_name='ont.rpc.manager.GetVersionInfoResponse.distribution_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='distribution_status', full_name='ont.rpc.manager.GetVersionInfoResponse.distribution_status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='guppy_build_version', full_name='ont.rpc.manager.GetVersionInfoResponse.guppy_build_version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='guppy_connected_version', full_name='ont.rpc.manager.GetVersionInfoResponse.guppy_connected_version', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='configuration', full_name='ont.rpc.manager.GetVersionInfoResponse.configuration', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1751,
  serialized_end=2073,
)


_LISTPROTOCOLOUTPUTDIRFILESREQUEST = _descriptor.Descriptor(
  name='ListProtocolOutputDirFilesRequest',
  full_name='ont.rpc.manager.ListProtocolOutputDirFilesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ont.rpc.manager.ListProtocolOutputDirFilesRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2075,
  serialized_end=2124,
)


_LISTPROTOCOLOUTPUTDIRFILESRESPONSE_DIRECTORYINFO = _descriptor.Descriptor(
  name='DirectoryInfo',
  full_name='ont.rpc.manager.ListProtocolOutputDirFilesResponse.DirectoryInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='ont.rpc.manager.ListProtocolOutputDirFilesResponse.DirectoryInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='directory_count', full_name='ont.rpc.manager.ListProtocolOutputDirFilesResponse.DirectoryInfo.directory_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_count', full_name='ont.rpc.manager.ListProtocolOutputDirFilesResponse.DirectoryInfo.file_count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2297,
  serialized_end=2371,
)

_LISTPROTOCOLOUTPUTDIRFILESRESPONSE = _descriptor.Descriptor(
  name='ListProtocolOutputDirFilesResponse',
  full_name='ont.rpc.manager.ListProtocolOutputDirFilesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='directories', full_name='ont.rpc.manager.ListProtocolOutputDirFilesResponse.directories', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='files', full_name='ont.rpc.manager.ListProtocolOutputDirFilesResponse.files', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current_listed_path', full_name='ont.rpc.manager.ListProtocolOutputDirFilesResponse.current_listed_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LISTPROTOCOLOUTPUTDIRFILESRESPONSE_DIRECTORYINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2127,
  serialized_end=2371,
)


_CREATEDIRECTORYREQUEST = _descriptor.Descriptor(
  name='CreateDirectoryRequest',
  full_name='ont.rpc.manager.CreateDirectoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_path', full_name='ont.rpc.manager.CreateDirectoryRequest.parent_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='ont.rpc.manager.CreateDirectoryRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2373,
  serialized_end=2432,
)


_CREATEDIRECTORYRESPONSE = _descriptor.Descriptor(
  name='CreateDirectoryResponse',
  full_name='ont.rpc.manager.CreateDirectoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='ont.rpc.manager.CreateDirectoryResponse.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2434,
  serialized_end=2473,
)

_FLOWCELLPOSITION_LOCATION.containing_type = _FLOWCELLPOSITION
_FLOWCELLPOSITION_RPCPORTS.containing_type = _FLOWCELLPOSITION
_FLOWCELLPOSITION.fields_by_name['location'].message_type = _FLOWCELLPOSITION_LOCATION
_FLOWCELLPOSITION.fields_by_name['state'].enum_type = _FLOWCELLPOSITION_STATE
_FLOWCELLPOSITION.fields_by_name['rpc_ports'].message_type = _FLOWCELLPOSITION_RPCPORTS
_FLOWCELLPOSITION_STATE.containing_type = _FLOWCELLPOSITION
_FLOWCELLPOSITIONSRESPONSE.fields_by_name['positions'].message_type = _FLOWCELLPOSITION
_WATCHFLOWCELLPOSITIONSRESPONSE.fields_by_name['additions'].message_type = _FLOWCELLPOSITION
_WATCHFLOWCELLPOSITIONSRESPONSE.fields_by_name['changes'].message_type = _FLOWCELLPOSITION
_LISTDEVICESRESPONSE_RPCPORTS.containing_type = _LISTDEVICESRESPONSE
_LISTDEVICESRESPONSE_DEVICELAYOUT.containing_type = _LISTDEVICESRESPONSE
_LISTDEVICESRESPONSE_ACTIVEDEVICE.fields_by_name['ports'].message_type = _LISTDEVICESRESPONSE_RPCPORTS
_LISTDEVICESRESPONSE_ACTIVEDEVICE.fields_by_name['layout'].message_type = _LISTDEVICESRESPONSE_DEVICELAYOUT
_LISTDEVICESRESPONSE_ACTIVEDEVICE.containing_type = _LISTDEVICESRESPONSE
_LISTDEVICESRESPONSE.fields_by_name['active'].message_type = _LISTDEVICESRESPONSE_ACTIVEDEVICE
_GETVERSIONINFORESPONSE.fields_by_name['minknow'].message_type = minknow_dot_rpc_dot_instance__pb2._GETVERSIONINFORESPONSE_MINKNOWVERSION
_GETVERSIONINFORESPONSE.fields_by_name['distribution_status'].enum_type = minknow_dot_rpc_dot_instance__pb2._GETVERSIONINFORESPONSE_DISTRIBUTIONSTATUS
_LISTPROTOCOLOUTPUTDIRFILESRESPONSE_DIRECTORYINFO.containing_type = _LISTPROTOCOLOUTPUTDIRFILESRESPONSE
_LISTPROTOCOLOUTPUTDIRFILESRESPONSE.fields_by_name['directories'].message_type = _LISTPROTOCOLOUTPUTDIRFILESRESPONSE_DIRECTORYINFO
DESCRIPTOR.message_types_by_name['DescribeHostRequest'] = _DESCRIBEHOSTREQUEST
DESCRIPTOR.message_types_by_name['DescribeHostResponse'] = _DESCRIBEHOSTRESPONSE
DESCRIPTOR.message_types_by_name['FlowCellPosition'] = _FLOWCELLPOSITION
DESCRIPTOR.message_types_by_name['FlowCellPositionsRequest'] = _FLOWCELLPOSITIONSREQUEST
DESCRIPTOR.message_types_by_name['FlowCellPositionsResponse'] = _FLOWCELLPOSITIONSRESPONSE
DESCRIPTOR.message_types_by_name['WatchFlowCellPositionsRequest'] = _WATCHFLOWCELLPOSITIONSREQUEST
DESCRIPTOR.message_types_by_name['WatchFlowCellPositionsResponse'] = _WATCHFLOWCELLPOSITIONSRESPONSE
DESCRIPTOR.message_types_by_name['ResetPositionRequest'] = _RESETPOSITIONREQUEST
DESCRIPTOR.message_types_by_name['ResetPositionResponse'] = _RESETPOSITIONRESPONSE
DESCRIPTOR.message_types_by_name['ListDevicesRequest'] = _LISTDEVICESREQUEST
DESCRIPTOR.message_types_by_name['ListDevicesResponse'] = _LISTDEVICESRESPONSE
DESCRIPTOR.message_types_by_name['BasecallerApiRequest'] = _BASECALLERAPIREQUEST
DESCRIPTOR.message_types_by_name['BasecallerApiResponse'] = _BASECALLERAPIRESPONSE
DESCRIPTOR.message_types_by_name['GetVersionInfoRequest'] = _GETVERSIONINFOREQUEST
DESCRIPTOR.message_types_by_name['GetVersionInfoResponse'] = _GETVERSIONINFORESPONSE
DESCRIPTOR.message_types_by_name['ListProtocolOutputDirFilesRequest'] = _LISTPROTOCOLOUTPUTDIRFILESREQUEST
DESCRIPTOR.message_types_by_name['ListProtocolOutputDirFilesResponse'] = _LISTPROTOCOLOUTPUTDIRFILESRESPONSE
DESCRIPTOR.message_types_by_name['CreateDirectoryRequest'] = _CREATEDIRECTORYREQUEST
DESCRIPTOR.message_types_by_name['CreateDirectoryResponse'] = _CREATEDIRECTORYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DescribeHostRequest = _reflection.GeneratedProtocolMessageType('DescribeHostRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEHOSTREQUEST,
  '__module__' : 'minknow.rpc.manager_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.manager.DescribeHostRequest)
  })
_sym_db.RegisterMessage(DescribeHostRequest)

DescribeHostResponse = _reflection.GeneratedProtocolMessageType('DescribeHostResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEHOSTRESPONSE,
  '__module__' : 'minknow.rpc.manager_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.manager.DescribeHostResponse)
  })
_sym_db.RegisterMessage(DescribeHostResponse)

FlowCellPosition = _reflection.GeneratedProtocolMessageType('FlowCellPosition', (_message.Message,), {

  'Location' : _reflection.GeneratedProtocolMessageType('Location', (_message.Message,), {
    'DESCRIPTOR' : _FLOWCELLPOSITION_LOCATION,
    '__module__' : 'minknow.rpc.manager_pb2'
    # @@protoc_insertion_point(class_scope:ont.rpc.manager.FlowCellPosition.Location)
    })
  ,

  'RpcPorts' : _reflection.GeneratedProtocolMessageType('RpcPorts', (_message.Message,), {
    'DESCRIPTOR' : _FLOWCELLPOSITION_RPCPORTS,
    '__module__' : 'minknow.rpc.manager_pb2'
    # @@protoc_insertion_point(class_scope:ont.rpc.manager.FlowCellPosition.RpcPorts)
    })
  ,
  'DESCRIPTOR' : _FLOWCELLPOSITION,
  '__module__' : 'minknow.rpc.manager_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.manager.FlowCellPosition)
  })
_sym_db.RegisterMessage(FlowCellPosition)
_sym_db.RegisterMessage(FlowCellPosition.Location)
_sym_db.RegisterMessage(FlowCellPosition.RpcPorts)

FlowCellPositionsRequest = _reflection.GeneratedProtocolMessageType('FlowCellPositionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _FLOWCELLPOSITIONSREQUEST,
  '__module__' : 'minknow.rpc.manager_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.manager.FlowCellPositionsRequest)
  })
_sym_db.RegisterMessage(FlowCellPositionsRequest)

FlowCellPositionsResponse = _reflection.GeneratedProtocolMessageType('FlowCellPositionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _FLOWCELLPOSITIONSRESPONSE,
  '__module__' : 'minknow.rpc.manager_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.manager.FlowCellPositionsResponse)
  })
_sym_db.RegisterMessage(FlowCellPositionsResponse)

WatchFlowCellPositionsRequest = _reflection.GeneratedProtocolMessageType('WatchFlowCellPositionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHFLOWCELLPOSITIONSREQUEST,
  '__module__' : 'minknow.rpc.manager_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.manager.WatchFlowCellPositionsRequest)
  })
_sym_db.RegisterMessage(WatchFlowCellPositionsRequest)

WatchFlowCellPositionsResponse = _reflection.GeneratedProtocolMessageType('WatchFlowCellPositionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _WATCHFLOWCELLPOSITIONSRESPONSE,
  '__module__' : 'minknow.rpc.manager_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.manager.WatchFlowCellPositionsResponse)
  })
_sym_db.RegisterMessage(WatchFlowCellPositionsResponse)

ResetPositionRequest = _reflection.GeneratedProtocolMessageType('ResetPositionRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESETPOSITIONREQUEST,
  '__module__' : 'minknow.rpc.manager_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.manager.ResetPositionRequest)
  })
_sym_db.RegisterMessage(ResetPositionRequest)

ResetPositionResponse = _reflection.GeneratedProtocolMessageType('ResetPositionResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESETPOSITIONRESPONSE,
  '__module__' : 'minknow.rpc.manager_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.manager.ResetPositionResponse)
  })
_sym_db.RegisterMessage(ResetPositionResponse)

ListDevicesRequest = _reflection.GeneratedProtocolMessageType('ListDevicesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDEVICESREQUEST,
  '__module__' : 'minknow.rpc.manager_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.manager.ListDevicesRequest)
  })
_sym_db.RegisterMessage(ListDevicesRequest)

ListDevicesResponse = _reflection.GeneratedProtocolMessageType('ListDevicesResponse', (_message.Message,), {

  'RpcPorts' : _reflection.GeneratedProtocolMessageType('RpcPorts', (_message.Message,), {
    'DESCRIPTOR' : _LISTDEVICESRESPONSE_RPCPORTS,
    '__module__' : 'minknow.rpc.manager_pb2'
    # @@protoc_insertion_point(class_scope:ont.rpc.manager.ListDevicesResponse.RpcPorts)
    })
  ,

  'DeviceLayout' : _reflection.GeneratedProtocolMessageType('DeviceLayout', (_message.Message,), {
    'DESCRIPTOR' : _LISTDEVICESRESPONSE_DEVICELAYOUT,
    '__module__' : 'minknow.rpc.manager_pb2'
    # @@protoc_insertion_point(class_scope:ont.rpc.manager.ListDevicesResponse.DeviceLayout)
    })
  ,

  'ActiveDevice' : _reflection.GeneratedProtocolMessageType('ActiveDevice', (_message.Message,), {
    'DESCRIPTOR' : _LISTDEVICESRESPONSE_ACTIVEDEVICE,
    '__module__' : 'minknow.rpc.manager_pb2'
    # @@protoc_insertion_point(class_scope:ont.rpc.manager.ListDevicesResponse.ActiveDevice)
    })
  ,
  'DESCRIPTOR' : _LISTDEVICESRESPONSE,
  '__module__' : 'minknow.rpc.manager_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.manager.ListDevicesResponse)
  })
_sym_db.RegisterMessage(ListDevicesResponse)
_sym_db.RegisterMessage(ListDevicesResponse.RpcPorts)
_sym_db.RegisterMessage(ListDevicesResponse.DeviceLayout)
_sym_db.RegisterMessage(ListDevicesResponse.ActiveDevice)

BasecallerApiRequest = _reflection.GeneratedProtocolMessageType('BasecallerApiRequest', (_message.Message,), {
  'DESCRIPTOR' : _BASECALLERAPIREQUEST,
  '__module__' : 'minknow.rpc.manager_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.manager.BasecallerApiRequest)
  })
_sym_db.RegisterMessage(BasecallerApiRequest)

BasecallerApiResponse = _reflection.GeneratedProtocolMessageType('BasecallerApiResponse', (_message.Message,), {
  'DESCRIPTOR' : _BASECALLERAPIRESPONSE,
  '__module__' : 'minknow.rpc.manager_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.manager.BasecallerApiResponse)
  })
_sym_db.RegisterMessage(BasecallerApiResponse)

GetVersionInfoRequest = _reflection.GeneratedProtocolMessageType('GetVersionInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVERSIONINFOREQUEST,
  '__module__' : 'minknow.rpc.manager_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.manager.GetVersionInfoRequest)
  })
_sym_db.RegisterMessage(GetVersionInfoRequest)

GetVersionInfoResponse = _reflection.GeneratedProtocolMessageType('GetVersionInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVERSIONINFORESPONSE,
  '__module__' : 'minknow.rpc.manager_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.manager.GetVersionInfoResponse)
  })
_sym_db.RegisterMessage(GetVersionInfoResponse)

ListProtocolOutputDirFilesRequest = _reflection.GeneratedProtocolMessageType('ListProtocolOutputDirFilesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROTOCOLOUTPUTDIRFILESREQUEST,
  '__module__' : 'minknow.rpc.manager_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.manager.ListProtocolOutputDirFilesRequest)
  })
_sym_db.RegisterMessage(ListProtocolOutputDirFilesRequest)

ListProtocolOutputDirFilesResponse = _reflection.GeneratedProtocolMessageType('ListProtocolOutputDirFilesResponse', (_message.Message,), {

  'DirectoryInfo' : _reflection.GeneratedProtocolMessageType('DirectoryInfo', (_message.Message,), {
    'DESCRIPTOR' : _LISTPROTOCOLOUTPUTDIRFILESRESPONSE_DIRECTORYINFO,
    '__module__' : 'minknow.rpc.manager_pb2'
    # @@protoc_insertion_point(class_scope:ont.rpc.manager.ListProtocolOutputDirFilesResponse.DirectoryInfo)
    })
  ,
  'DESCRIPTOR' : _LISTPROTOCOLOUTPUTDIRFILESRESPONSE,
  '__module__' : 'minknow.rpc.manager_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.manager.ListProtocolOutputDirFilesResponse)
  })
_sym_db.RegisterMessage(ListProtocolOutputDirFilesResponse)
_sym_db.RegisterMessage(ListProtocolOutputDirFilesResponse.DirectoryInfo)

CreateDirectoryRequest = _reflection.GeneratedProtocolMessageType('CreateDirectoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDIRECTORYREQUEST,
  '__module__' : 'minknow.rpc.manager_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.manager.CreateDirectoryRequest)
  })
_sym_db.RegisterMessage(CreateDirectoryRequest)

CreateDirectoryResponse = _reflection.GeneratedProtocolMessageType('CreateDirectoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDIRECTORYRESPONSE,
  '__module__' : 'minknow.rpc.manager_pb2'
  # @@protoc_insertion_point(class_scope:ont.rpc.manager.CreateDirectoryResponse)
  })
_sym_db.RegisterMessage(CreateDirectoryResponse)



_MANAGERSERVICE = _descriptor.ServiceDescriptor(
  name='ManagerService',
  full_name='ont.rpc.manager.ManagerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2476,
  serialized_end=3476,
  methods=[
  _descriptor.MethodDescriptor(
    name='describe_host',
    full_name='ont.rpc.manager.ManagerService.describe_host',
    index=0,
    containing_service=None,
    input_type=_DESCRIBEHOSTREQUEST,
    output_type=_DESCRIBEHOSTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='list_devices',
    full_name='ont.rpc.manager.ManagerService.list_devices',
    index=1,
    containing_service=None,
    input_type=_LISTDEVICESREQUEST,
    output_type=_LISTDEVICESRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='flow_cell_positions',
    full_name='ont.rpc.manager.ManagerService.flow_cell_positions',
    index=2,
    containing_service=None,
    input_type=_FLOWCELLPOSITIONSREQUEST,
    output_type=_FLOWCELLPOSITIONSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='watch_flow_cell_positions',
    full_name='ont.rpc.manager.ManagerService.watch_flow_cell_positions',
    index=3,
    containing_service=None,
    input_type=_WATCHFLOWCELLPOSITIONSREQUEST,
    output_type=_WATCHFLOWCELLPOSITIONSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='reset_position',
    full_name='ont.rpc.manager.ManagerService.reset_position',
    index=4,
    containing_service=None,
    input_type=_RESETPOSITIONREQUEST,
    output_type=_RESETPOSITIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='basecaller_api',
    full_name='ont.rpc.manager.ManagerService.basecaller_api',
    index=5,
    containing_service=None,
    input_type=_BASECALLERAPIREQUEST,
    output_type=_BASECALLERAPIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_version_info',
    full_name='ont.rpc.manager.ManagerService.get_version_info',
    index=6,
    containing_service=None,
    input_type=_GETVERSIONINFOREQUEST,
    output_type=_GETVERSIONINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='list_protocol_output_dir_files',
    full_name='ont.rpc.manager.ManagerService.list_protocol_output_dir_files',
    index=7,
    containing_service=None,
    input_type=_LISTPROTOCOLOUTPUTDIRFILESREQUEST,
    output_type=_LISTPROTOCOLOUTPUTDIRFILESRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='create_directory',
    full_name='ont.rpc.manager.ManagerService.create_directory',
    index=8,
    containing_service=None,
    input_type=_CREATEDIRECTORYREQUEST,
    output_type=_CREATEDIRECTORYRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_MANAGERSERVICE)

DESCRIPTOR.services_by_name['ManagerService'] = _MANAGERSERVICE

# @@protoc_insertion_point(module_scope)
